telegram
========

This subpackage contains the functionality for creating the telegrams used to
communicate with the TURBOVAC pump.

.. toctree::
   
    datatypes.rst
    codes.rst
    parser.rst
    telegram.rst
    api.rst
